<?php
/**
 * The Wedding functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package The_Wedding
 */

/**
 * The_Wedding only works in WordPress 4.4 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.4-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'the_wedding_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function the_wedding_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on The Wedding, use a find and replace
	 * to change 'the-wedding' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'the-wedding', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );

	// Set detfault Post Thumbnail size
	set_post_thumbnail_size( 900, 400, true );

	// This theme uses wp_nav_menu() in two location.
	register_nav_menus( array(
		'primary' => 'Main Navigation',
		'footer' => 'Footer Menu',
	) );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'the_wedding_custom_background_args', array( 'default-color' => 'ffffff', 'default-image' => '' ) ) );

	// Set up the WordPress core custom logo feature
	add_theme_support( 'custom-logo', apply_filters( 'the_wedding_custom_logo_args', array(
		'flex-height' => true,
		'flex-width' => true,
	) ) );

	add_filter('paginate_links','change_paginate_class');
	function change_paginate_class($html){
		$html = str_replace('page-numbers', 'pagination pagination-lg', $html);
		return $html;
	}

	// Set up the WordPress core custom header feature.
	add_theme_support( 'custom-header', apply_filters( 'the_wedding_custom_header_args', array(
		'flex-width'    => true,
		'default-image'	=> get_template_directory_uri() . '/images/banner/header.jpg',
		'header-text'	=> false,
		'width'			=> 1600,
		'height'		=> 670,
		'flex-height'	=> true
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/images/banner/header.jpg',
			'thumbnail_url' => '%s/images/banner/header.jpg',
			'description'   => __( 'Default Header Image', 'the-wedding' ),
		),
	) );

	// Add Theme Support for wooCommerce
	add_theme_support( 'woocommerce' );

	// Add extra theme styling to the visual editor
	add_editor_style( array( 'css/editor-style.css', the_wedding_google_fonts_url() ) );

	// Add Theme Support for Selective Refresh in Customizer
	add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'the_wedding_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function the_wedding_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'the_wedding_content_width', 640 );
}
add_action( 'after_setup_theme', 'the_wedding_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function the_wedding_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'the-wedding' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'the-wedding' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h4>',
		'after_title'   => '</h4></div>',
	) );
}
add_action( 'widgets_init', 'the_wedding_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function the_wedding_scripts() {
	// Get Theme Version
	$theme_version = wp_get_theme()->get( 'Version' );

	// Register website.min.css
	wp_enqueue_style( 'the-wedding-website-min', get_template_directory_uri() . '/css/website.min.css', array() );

	// Register and Enqueue Google Fonts
	wp_enqueue_style( 'the-wedding-default-fonts', the_wedding_google_fonts_url(), array(), null );

	// Register and Enqueue Stylesheet
	wp_enqueue_style( 'the-wedding-style', get_stylesheet_uri(), array(), filemtime( get_stylesheet_directory() . '/style.css' ) );

	// Register responsive.css
	wp_enqueue_style( 'the-wedding-responsive', get_template_directory_uri() . '/css/responsive.css', array() );

	// Register and Enqueue HTML5shiv and Respond.js to support HTML5 elements in older IE versions
	wp_enqueue_script( 'the-wedding-html5shiv', get_template_directory_uri() . '/js/html5shiv.min.js', array(), $theme_version );
	wp_script_add_data( 'the-wedding-html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'the-wedding-respond', get_template_directory_uri() . '/js/respond.min.js', array(), $theme_version );
	wp_script_add_data( 'the-wedding-respond', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'the-wedding-bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array(), $theme_version, true );

	wp_enqueue_script( 'the-wedding-website-script', get_template_directory_uri() . '/js/website.min.js', array(), $theme_version, true );

	wp_enqueue_script( 'the-wedding-custom-script', get_template_directory_uri() . '/js/custom-min.js', array( 'jquery' ), $theme_version, true );

	// wp_enqueue_script( 'the-wedding-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'the-wedding-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'the_wedding_scripts' );

/**
	 * Enqueue the styles and scripts
	**/
	function my_enqueue_customizer_stylesheet()
	{
		wp_register_style( 'the-wedding-gfont-style', get_template_directory_uri() . '/assets/styles.css', NULL, NULL, 'all' );
		wp_enqueue_style( 'the-wedding-gfont-style' );
		wp_register_script( 'the-wedding-gfont-script', get_template_directory_uri() . '/assets/script.js', array(), '20160729', true );
		wp_enqueue_script( 'the-wedding-gfont-script' );
		wp_register_style( 'the-wedding-cusg-fonts', the_wedding_cusg_fonts_url(), array(), null );
		wp_enqueue_style( 'the-wedding-cusg-fonts' );
	}
	add_action( 'customize_controls_print_styles', 'my_enqueue_customizer_stylesheet' );

	/**
 * Retrieve Font URL to register default Google Fonts
 */
function the_wedding_cusg_fonts_url() {

	// Set default Fonts
	$font_families = array( 'Abel|Arimo:400,400i,700,700i|Bree+Serif|Dancing+Script:400,700|Dosis:400,500,600,700,800|Droid+Sans:400,700|Droid+Serif:400,400i,700,700i|Kaushan+Script|Lato:400,400i,700,700i,900,900i|Libre+Baskerville:400,400i,700' );

	// Build Fonts URL
	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		//'subset' => urlencode( 'latin,latin-ext' ),
	);
	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

    return apply_filters( 'the_wedding_cusg_fonts_url', $fonts_url );
}

/**
 * Retrieve Font URL to register default Google Fonts
 */
function the_wedding_google_fonts_url() {

	// Set default Fonts
	$font_families = array( 'Libre Baskerville:400,400i|Great Vibes' );

	// Build Fonts URL
	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) )
	);
	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

    return apply_filters( 'the_wedding_google_fonts_url', $fonts_url );
}

/**
 * Include Files
 */

// include Theme Customizer Options
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/customizer/default-options.php';

// Include Extra Functions
require get_template_directory() . '/inc/extras.php';

// include Template Functions
require get_template_directory() . '/inc/template-tags.php';

function wpb_set_post_views($postID) {
    $count_key = 'wpb_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}
//To keep the count accurate, lets get rid of prefetching
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

function wpb_track_post_views ($post_id) {
    if ( !is_single() ) return;
    if ( empty ( $post_id) ) {
        global $post;
        $post_id = $post->ID;
    }
    wpb_set_post_views($post_id);
}
add_action( 'wp_head', 'wpb_track_post_views');

function wpb_get_post_views($postID){
    $count_key = 'wpb_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0 View";
    }
    return $count.' Views';
}

class The_Wedding_Popular_Posts_Widget extends WP_Widget {

	/**
	 * Widget Constructor
	 */
	function __construct() {

		// Setup Widget.
		parent::__construct(
			'the-wedding-popular-posts', // ID.
			sprintf( esc_html__( 'Popular & Commented Posts (%s)', 'the-wedding' ), wp_get_theme()->Name ), // Name.
			array(
				'classname' => 'the-wedding-popular-posts',
				'description' => esc_html__( 'Display popular and commented posts in a tabular view', 'the-wedding' ),
				'customize_selective_refresh' => true,
			) // Args.
		);

		// Delete Widget Cache on certain actions.
		add_action( 'save_post', array( $this, 'delete_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'delete_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'delete_widget_cache' ) );

	}


	/**
	 * Set default settings of the widget
	 */
	private function default_settings() {

		$defaults = array(
			'title' => '',
		);

		return $defaults;

	}


	/**
	 * Main Function to display the widget
	 *
	 * @uses this->render()
	 *
	 * @param array $args / Parameters from widget area created with register_sidebar().
	 * @param array $instance / Settings for this widget instance.
	 */
	function widget( $args, $instance ) {

		$cache = array();

		// Get Widget Object Cache.
		if ( ! $this->is_preview() ) {
			$cache = wp_cache_get( 'widget_the_wedding_popular_posts', 'widget' );
		}
		if ( ! is_array( $cache ) ) {
			$cache = array();
		}

		// Display Widget from Cache if exists.
		if ( isset( $cache[ $this->id ] ) ) {
			echo $cache[ $this->id ];
			return;
		}

		// Start Output Buffering.
		ob_start();

		// Get Widget Settings.
		$settings = wp_parse_args( $instance, $this->default_settings() );

		// Output.
		echo $args['before_widget'];
		?>

		<?php // Display Title.
			$this->widget_title( $args, $settings ); ?>

			<?php $this->render( $settings ); ?>

		<?php
		echo $args['after_widget'];

		// Set Cache.
		if ( ! $this->is_preview() ) {
			$cache[ $this->id ] = ob_get_flush();
			wp_cache_set( 'widget_the_wedding_popular_posts', $cache, 'widget' );
		} else {
			ob_end_flush();
		}

	}


	/**
	 * Renders the Widget Content
	 *
	 * Switches between horizontal and vertical layout style based on widget settings
	 *
	 * @uses this->magazine_posts_horizontal() or this->magazine_posts_vertical()
	 * @used-by this->widget()
	 *
	 * @param array $settings / Settings for this widget instance.
	 */
	function render( $settings ) { ?>

			<div class="widget-tab">
				<ul class="nav-tabs">
					<li class="active"><a href="#Popular" data-toggle="tab"><?php printf( esc_html__( 'Popular', 'the-wedding' ) ); ?></a></li>
					<li><a href="#Commented" data-toggle="tab"><?php printf( esc_html__( 'Commented', 'the-wedding' ) ); ?></a></li>
				</ul>
			</div>
			<div class="widget-body">
				<div class="tab-content">
					<div class="tab-pane fade in active" id="Popular">
						<ul class="recent-posts">
							<?php
								$popularpost = new WP_Query( array( 'posts_per_page'=>4, 'meta_key' => 'wpb_post_views_count', 'orderby' => 'meta_value_num', 'order' => 'DESC'  ) );
								while ( $popularpost->have_posts() ) : $popularpost->the_post();
									global $post;?>
									<li>
										<div class="holder">
											<div class="pic">
												<?php if ( has_post_thumbnail() ): ?>
													<?php the_post_thumbnail('full',array()); ?>
												<?php else:?>
													<img src="http://placehold.it/100x100">
												<?php endif; ?>
											</div>
											<div class="data">
												<?php the_title( sprintf( '<h5><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h5>' ); ?>
												<?php the_excerpt(); ?>
											</div>
										</div>
									</li>
									<?php

								endwhile;
								wp_reset_postdata();
							?>
						</ul>
					</div>
					<div class="tab-pane fade" id="Commented">
						<ul class="recent-posts">
							<?php
								$commentedpost = new WP_Query( array( 'posts_per_page'=>4, 'order' => 'DESC', 'orderby' =>'comment_count'  ) );
								while ( $commentedpost->have_posts() ) : $commentedpost->the_post();
								global $post;
								if (0 < $post->comment_count) :?>
									<li>
										<div class="holder">
											<div class="pic">
												<?php if ( has_post_thumbnail() ): ?>
													<?php the_post_thumbnail('full',array()); ?>
												<?php else:?>
													<img src="http://placehold.it/100x100">
												<?php endif; ?>
											</div>
											<div class="data">
												<?php the_title( sprintf( '<h5><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h5>' ); ?>
												<?php the_excerpt(); ?>
											</div>
										</div>
									</li>
								<?php endif; endwhile; ?>
						</ul>
					</div>
				</div>
			</div>

		<?php
	}


	/**
	 * Displays Widget Title
	 *
	 * @param array $args / Parameters from widget area created with register_sidebar().
	 * @param array $settings / Settings for this widget instance.
	 */
	function widget_title( $args, $settings ) {

		// Add Widget Title Filter.
		$widget_title = apply_filters( 'widget_title', $settings['title'], $settings, $this->id_base );

		if ( ! empty( $widget_title ) ) :
				echo $args['before_title'] . $widget_title . $args['after_title'];
		endif;

	} // widget_title()


	/**
	 * Update Widget Settings
	 *
	 * @param array $new_instance / New Settings for this widget instance.
	 * @param array $old_instance / Old Settings for this widget instance.
	 * @return array $instance
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );

		$this->delete_widget_cache();

		return $instance;
	}


	/**
	 * Displays Widget Settings Form in the Backend
	 *
	 * @param array $instance / Settings for this widget instance.
	 */
	function form( $instance ) {

		// Get Widget Settings.
		$settings = wp_parse_args( $instance, $this->default_settings() );
?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'the-wedding' ); ?>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $settings['title']; ?>" />
			</label>
		</p>
<?php
	} // form()


	/**
	 * Delete Widget Cache
	 */
	public function delete_widget_cache() {

		wp_cache_delete( 'widget_the_wedding_popular_posts', 'widget' );

	}
}

/**
 * Register Widget
 */
function the_wedding_register_popular_posts_widget() {

	register_widget( 'The_Wedding_Popular_Posts_Widget' );

}
add_action( 'widgets_init', 'the_wedding_register_popular_posts_widget' );

function tag_cloud_filter($args = array()) {
 $args['smallest'] = 14;
 $args['largest'] = 22;
 $args['unit'] = 'px';
 return $args;
}
add_filter('widget_tag_cloud_args', 'tag_cloud_filter', 90);

function get_hansel_and_gretel_breadcrumbs()
{
    // Set variables for later use
    $home_link        = home_url('/');
    $home_text        = __( 'Home', 'the-wedding' );
    $link_before      = '<li>';
    $link_after       = '</li>';
    $link_attr        = '';
    $link             = $link_before . '<a href="%1$s">%2$s</a>' . $link_after;
    $delimiter        = '';              // Delimiter between crumbs
    $before           = '<li class="active">'; // Tag before the current crumb
    $after            = '</li>';                // Tag after the current crumb
    $page_addon       = '';                       // Adds the page number if the query is paged
    $breadcrumb_trail = '';
    $category_links   = '';

    /** 
     * Set our own $wp_the_query variable. Do not use the global variable version due to 
     * reliability
     */
    $wp_the_query   = $GLOBALS['wp_the_query'];
    $queried_object = $wp_the_query->get_queried_object();

    // Handle single post requests which includes single pages, posts and attatchments
    if ( is_singular() ) 
    {
        /** 
         * Set our own $post variable. Do not use the global variable version due to 
         * reliability. We will set $post_object variable to $GLOBALS['wp_the_query']
         */
        $post_object = sanitize_post( $queried_object );

        // Set variables 
        $title          = apply_filters( 'the_title', $post_object->post_title );
        $parent         = $post_object->post_parent;
        $post_type      = $post_object->post_type;
        $post_id        = $post_object->ID;
        $post_link      = $before . $title . $after;
        $parent_string  = '';
        $post_type_link = '';
        $custom_title = apply_filters( 'the_title', $post_object->post_title );

        if ( 'post' === $post_type ) 
        {
            // Get the post categories
            $categories = get_the_category( $post_id );
            if ( $categories ) {
                // Lets grab the first category
                $category  = $categories[0];

                $category_links = get_category_parents( $category, true, $delimiter );
                $category_links = str_replace( '<a',   $link_before . '<a' . $link_attr, $category_links );
                $category_links = str_replace( '</a>', '</a>' . $link_after,             $category_links );
            }
        }

        if ( !in_array( $post_type, ['post', 'page', 'attachment'] ) )
        {
            $post_type_object = get_post_type_object( $post_type );
            $archive_link     = esc_url( get_post_type_archive_link( $post_type ) );

            $post_type_link   = sprintf( $link, $archive_link, $post_type_object->labels->singular_name );
        }

        // Get post parents if $parent !== 0
        if ( 0 !== $parent ) 
        {
            $parent_links = [];
            while ( $parent ) {
                $post_parent = get_post( $parent );

                $parent_links[] = sprintf( $link, esc_url( get_permalink( $post_parent->ID ) ), get_the_title( $post_parent->ID ) );

                $parent = $post_parent->post_parent;
            }

            $parent_links = array_reverse( $parent_links );

            $parent_string = implode( $delimiter, $parent_links );
        }

        // Lets build the breadcrumb trail
        if ( $parent_string ) {
            $breadcrumb_trail = $parent_string . $delimiter . $post_link;
        } else {
            $breadcrumb_trail = $post_link;
        }

        if ( $post_type_link )
            $breadcrumb_trail = $post_type_link . $delimiter . $breadcrumb_trail;

        if ( $category_links )
            $breadcrumb_trail = $category_links . $breadcrumb_trail;
    }

    // Handle archives which includes category-, tag-, taxonomy-, date-, custom post type archives and author archives
    if( is_archive() )
    {
        if ( is_category() || is_tag() || is_tax() ) {
            // Set the variables for this section
            $term_object        = get_term( $queried_object );
            $taxonomy           = $term_object->taxonomy;
            $term_id            = $term_object->term_id;
            $term_name          = $term_object->name;
            $term_parent        = $term_object->parent;
            $taxonomy_object    = get_taxonomy( $taxonomy );
            $current_term_link  = $before . $taxonomy_object->labels->singular_name . ': ' . $term_name . $after;
            $parent_term_string = '';
            $custom_title = $taxonomy_object->labels->singular_name . ': ' . $term_name . $after;


            if ( 0 !== $term_parent )
            {
                // Get all the current term ancestors
                $parent_term_links = [];
                while ( $term_parent ) {
                    $term = get_term( $term_parent, $taxonomy );

                    $parent_term_links[] = sprintf( $link, esc_url( get_term_link( $term ) ), $term->name );

                    $term_parent = $term->parent;
                }

                $parent_term_links  = array_reverse( $parent_term_links );
                $parent_term_string = implode( $delimiter, $parent_term_links );
            }

            if ( $parent_term_string ) {
                $breadcrumb_trail = $parent_term_string . $delimiter . $current_term_link;
            } else {
                $breadcrumb_trail = $current_term_link;
            }

        } elseif ( is_author() ) {

            $breadcrumb_trail = $before. __( 'Author archive for ', 'the-wedding') . $queried_object->data->display_name . $after;
            $custom_title = __( 'Archive: Author', 'the-wedding');

        } elseif ( is_date() ) {
            // Set default variables
            $year     = $wp_the_query->query_vars['year'];
            $monthnum = $wp_the_query->query_vars['monthnum'];
            $day      = $wp_the_query->query_vars['day'];

            // Get the month name if $monthnum has a value
            if ( $monthnum ) {
                $date_time  = DateTime::createFromFormat( '!m', $monthnum );
                $month_name = $date_time->format( 'F' );
            }

            if ( is_year() ) {

                $breadcrumb_trail = $before . $year . $after;
                $custom_title = __( 'Archive: Yearly', 'the-wedding');

            } elseif( is_month() ) {

                $year_link        = sprintf( $link, esc_url( get_year_link( $year ) ), $year );

                $breadcrumb_trail = $year_link . $delimiter . $before . $month_name . $after;
                $custom_title = __( 'Archive: Monthly', 'the-wedding');

            } elseif( is_day() ) {

                $year_link        = sprintf( $link, esc_url( get_year_link( $year ) ),             $year       );
                $month_link       = sprintf( $link, esc_url( get_month_link( $year, $monthnum ) ), $month_name );

                $breadcrumb_trail = $year_link . $delimiter . $month_link . $delimiter . $before . $day . $after;
                $custom_title = __( 'Archive: Daywise', 'the-wedding');
            }

        } elseif ( is_post_type_archive() ) {

            $post_type        = $wp_the_query->query_vars['post_type'];
            $post_type_object = get_post_type_object( $post_type );

            $breadcrumb_trail = $before . $post_type_object->labels->singular_name . $after;
            $custom_title = $post_type_object->labels->singular_name;

        }
    }   

    // Handle the search page
    if ( is_search() ) {
        $breadcrumb_trail = __( 'Search query for: ', 'the-wedding' ) . $before . get_search_query() . $after;
    }

    // Handle 404's
    if ( is_404() ) {
    	$custom_title = __('404 Page', 'the-wedding');
        $breadcrumb_trail = $before . __( 'Error 404', 'the-wedding' ) . $after;
    }

    // Handle paged pages
    if ( is_paged() ) {
        $current_page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' );
        $page_addon   = $before . sprintf( __( ' ( Page %s )', 'the-wedding' ), number_format_i18n( $current_page ) ) . $after;
    }

    $breadcrumb_output_link  = '';
    $breadcrumb_output_link .= '<div class="inner_banner">';
    $breadcrumb_output_link .= '<p class="title">'.$custom_title.'</p>';
    $breadcrumb_output_link .= '<ol class="breadcrumb">';
    if (    is_home()
         || is_front_page()
    ) {
        // Do not show breadcrumbs on page one of home and frontpage
        if ( is_paged() ) {
            $breadcrumb_output_link .= '<a href="' . $home_link . '">' . $home_text . '</a>';
            $breadcrumb_output_link .= $page_addon;
        }
    } else {
        $breadcrumb_output_link .= '<li><a href="' . $home_link . '">' . $home_text . '</a></li>';
        $breadcrumb_output_link .= $delimiter;
        $breadcrumb_output_link .= $breadcrumb_trail;
        $breadcrumb_output_link .= $page_addon;
    }
    $breadcrumb_output_link .= '</ol><!-- ol -->';
    $breadcrumb_output_link .= '</div><!-- .inner_banner -->';

    return $breadcrumb_output_link;
}

// require_once get_template_directory() . '/inc/tgm/tgm-init.php';