 <?php
/**
 * The-Wedding back compat functionality
 *
 * Prevents The-Wedding from running on WordPress versions prior to 4.4,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.4.
 *
 * @package The_Wedding
 *
 * Original Code: Twenty Sixteen http://wordpress.org/themes/The-Wedding
 * Original Copyright: the WordPress team and contributors.
 * 
 * The following code is a derivative work of the code from the Twenty Sixteen theme, 
 * which is licensed GPLv2 or later. This code therefore is also licensed under the terms 
 * of the GNU Public License, version 2.
 */

/**
 * Prevent switching to The-Wedding on old versions of WordPress.
 * Switches to the default theme.
 *
 */
function the_wedding_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );

	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'the_wedding_upgrade_notice' );
}
add_action( 'after_switch_theme', 'the_wedding_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * The-Wedding on WordPress versions prior to 4.4.
 *
 * @global string $wp_version WordPress version.
 */
function the_wedding_upgrade_notice() {
	$message = sprintf( esc_html__( '%1$s requires at least WordPress version %2$s. You are running version %3$s. Please upgrade and try again.', 'the-wedding' ), 'The-Wedding', '4.4', $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.4.
 *
 * @global string $wp_version WordPress version.
 */
function the_wedding_customize() {
	wp_die( sprintf( esc_html__( '%1$s requires at least WordPress version %2$s. You are running version %3$s. Please upgrade and try again.', 'the-wedding' ), 'The-Wedding', '4.4', $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'the_wedding_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.4.
 *
 * @global string $wp_version WordPress version.
 */
function the_wedding_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( esc_html__( '%1$s requires at least WordPress version %2$s. You are running version %3$s. Please upgrade and try again.', 'the-wedding' ), 'The-Wedding', '4.4', $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'the_wedding_preview' );