<?php
/**
 * Implement theme options in the Customizer
 *
 * @package The_Wedding
 */


// Load Customizer Helper Functions
require( get_template_directory() . '/inc/customizer/functions/custom-controls.php' );
require( get_template_directory() . '/inc/customizer/functions/sanitize-functions.php' );
require( get_template_directory() . '/inc/customizer/functions/callback-functions.php' );

// Load Customizer Section Files
require( get_template_directory() . '/inc/customizer/sections/customizer-general.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-website-text.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-color.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-typography.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-footer.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-post.php' );


/**
 * Registers Theme Options panel and sets up some WordPress core settings
 *
 */
function the_wedding_customize_register_options( $wp_customize ) {

	// Add Theme Options Panel
	$wp_customize->add_panel( 'the_wedding_options_panel', array(
		'priority'       => 180,
		'capability'     => 'edit_theme_options',
		'theme_supports' => '',
		'title'          => esc_html__( 'Theme Options', 'the-wedding' ),
		'description'    => '',
	) );

	// Add postMessage support for site title and description.
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Change default background section
	$wp_customize->get_control( 'background_color'  )->section   = 'background_image';
	$wp_customize->get_section( 'background_image'  )->title     = esc_html__( 'Background', 'the-wedding' );

	// Add Display Site Title Setting
	$wp_customize->add_setting( 'the_wedding_theme_options[site_title]', array(
       		'default'           => true,
		'type'           	=> 'option',
       		'transport'         => 'refresh',
       		'sanitize_callback' => 'the_wedding_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'the_wedding_theme_options[site_title]', array(
        'label'    => esc_html__( 'Display Site Title', 'the-wedding' ),
        'section'  => 'title_tagline',
        'settings' => 'the_wedding_theme_options[site_title]',
        'type'     => 'checkbox',
		'priority' => 10
		)
	);

	// Add Display Tagline Setting
	$wp_customize->add_setting( 'the_wedding_theme_options[site_description]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'the_wedding_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'the_wedding_theme_options[site_description]', array(
        'label'    => esc_html__( 'Display Tagline', 'the-wedding' ),
        'section'  => 'title_tagline',
        'settings' => 'the_wedding_theme_options[site_description]',
        'type'     => 'checkbox',
		'priority' => 11
		)
	);

	// Add Custom Header Hide Checkbox
	$wp_customize->add_setting( 'the_wedding_theme_options[custom_header_hide]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'the_wedding_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'the_wedding_control_custom_header_hide', array(
        'label'    => esc_html__( 'Hide header image on front page', 'the-wedding' ),
        'section'  => 'header_image',
        'settings' => 'the_wedding_theme_options[custom_header_hide]',
        'type'     => 'checkbox',
	'priority' => 15
	)
	);

} // the_wedding_customize_register_options()
add_action( 'customize_register', 'the_wedding_customize_register_options' );


/**
 * Embed JS file to make Theme Customizer preview reload changes asynchronously.
 *
 */
function the_wedding_customize_preview_js() {
	wp_enqueue_script( 'the_wedding-customizer-preview', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151202', true );
}
add_action( 'customize_preview_init', 'the_wedding_customize_preview_js' );


/**
 * Embed CSS styles for the theme options in the Customizer
 *
 */
function the_wedding_customize_preview_css() {
	wp_enqueue_style( 'the_wedding-customizer-css', get_template_directory_uri() . '/css/customizer.css', array(), '20151202' );
}
add_action( 'customize_controls_print_styles', 'the_wedding_customize_preview_css' );