<?php
/**
 * Returns theme options
 *
 * Uses sane defaults in case the user has not configured any theme options yet.
 *
 * @package The_Wedding
 */


/**
 * Get saved user settings from database or theme defaults
 *
 * @return array
 */
function the_wedding_theme_options() {
    
	// Merge Theme Options Array from Database with Default Options Array
	$theme_options = wp_parse_args( 
		
		// Get saved theme options from WP database
		get_option( 'the_wedding_theme_options', array() ), 
		
		// Merge with Default Options if setting was not saved yet
		the_wedding_default_options() 
		
	);

	// Return theme options
	return $theme_options;
	
}


/**
 * Returns the default settings of the theme
 *
 * @return array
 */
function the_wedding_default_options() {

	$default_options = array(
		'site_title'				=> true,
		'site_description'			=> true,
		'custom_header_link'		=> '',
		'custom_header_hide'		=> false,
		'layout' 					=> 'right-sidebar',
		'blog_title'				=> '',
		'blog_description'			=> '',
		'post_layout'				=> 'two-columns',
		'excerpt_length' 			=> 20,
		'meta_date'					=> true,
		'meta_author'				=> true,
		'meta_category'				=> true,
		'meta_comments'				=> true,
		'meta_tags'					=> true,
		'post_image_single'			=> true,
		'post_navigation'			=> true,
		'slider_magazine' 			=> false,
		'slider_blog' 				=> false,
		'slider_category' 			=> 0,
		'slider_limit' 				=> 8,
		'slider_animation' 			=> 'slide',
		'slider_speed' 				=> 7000,
		'primary_color'				=> '#e33846',
		'custom_select'				=> 'libre-baskerville',
		'footer_background'			=> '',
		'social_icons'				=> 'false',
		'social_icons_facebook'		=> '',
		'social_icons_twitter'		=> '',
		'social_icons_gplus'		=> '',
		'social_icons_pinterest'	=> '',
		'social_icons_youtube'		=> '',
		'social_icons_instagram'	=> '',
		'top_bar_search'			=> false,
		'footer_logo_check'			=> false,
		'copyr_text'				=> '',
		'footer_social_icons'		=> false,
		'hdr_image_text_one'		=> "We're getting married",
		'hdr_image_text_two'		=> "on August 19th 2016, Los Angeles",
		'txt_blk_title'				=> "The Wedding Theme",
		'txt_blk_subtitle'			=> "A Theme To Define The Season of Love",
		'txt_blk_content'			=> "It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English. Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for 'lorem ipsum' will uncover many web sites still in their infancy. Various versions have evolved over the years, sometimes by accident, sometimes on purpose (injected humour and the like).",
	);
	
	return $default_options;
}