<?php
/**
 * Callback Functions
 *
 * Used to determine whether an option setting is displayed or not. 
 * Called via the active_callback parameter of the add_control() function
 *
 * @package The_Wedding
 */

 
/**
 * Adds a callback function to retrieve wether post content is set to excerpt or not
 *
 * @param object $control / Instance of the Customizer Control 
 * @return bool
 */
function the_wedding_control_post_content_callback( $control ) {
	
	// Check if excerpt mode is selected
	if ( $control->manager->get_setting('the_wedding_theme_options[post_content]')->value() == 'excerpt' ) :
		return true;
	else :
		return false;
	endif;
	
}


/**
 * Adds a callback function to retrieve whether slider is activated or not
 *
 * @param object $control / Instance of the Customizer Control 
 * @return bool
 */
function the_wedding_slider_activated_callback( $control ) {
	
	// Check if Slider is turned on
	if ( $control->manager->get_setting('the_wedding_theme_options[slider_blog]')->value() == 1 ) :
		return true;
	elseif ( $control->manager->get_setting('the_wedding_theme_options[slider_magazine]')->value() == 1 ) :
		return true;
	else :
		return false;
	endif;
	
}

/**
 * Adds a callback function to retrieve whether social icons is activated or not
 *
 * @param object $control / Instance of the Customizer Control 
 * @return bool
 */
function the_wedding_top_social_activated_callback( $control ){
	// Check if social icons is activated
	if ( $control->manager->get_setting('the_wedding_theme_options[social_icons]')->value() == 1 ) :
		return true;	
	else :
		return false;
	endif;
}

/**
 * Adds a callback function to retrieve whether footer social icons is activated or not
 *
 * @param object $control / Instance of the Customizer Control 
 * @return bool
 */
function the_wedding_footer_social_activated_callback( $control ){
	// Check if footer social icons is activated
	if ( $control->manager->get_setting('the_wedding_theme_options[footer_social_icons]')->value() == 1 ) :
		return true;	
	else :
		return false;
	endif;
}

/**
 * Adds a callback function to retrieve whether footer logo is activated or not
 *
 * @param object $control / Instance of the Customizer Control 
 * @return bool
 */
function the_wedding_footLogo_activated_callback( $control ){
	// Check if footer logo is activated
	if ( $control->manager->get_setting('the_wedding_theme_options[footer_logo_check]')->value() == 1 ) :
		return true;	
	else :
		return false;
	endif;
}