<?php
/**
 * Custom Controls for the Customizer
 *
 * @package The_Wedding
 */


/**
 * Make sure that custom controls are only defined in the Customizer
 */
if ( class_exists( 'WP_Customize_Control' ) ) :

	/**
	 * Displays a bold label text. Used to create headlines for radio buttons and description sections.
	 *
	 */
	class The_Wedding_Customize_Header_Control extends WP_Customize_Control {

		public function render_content() {  ?>
			
			<label>
				<span class="customize-control-title"><?php echo wp_kses_post( $this->label ); ?></span>
			</label>
			
			<?php
		}
	}

	/**
	 * Displays a description text in gray italic font
	 *
	 */
	class The_Wedding_Customize_Description_Control extends WP_Customize_Control {

		public function render_content() {  ?>
			
			<span class="description"><?php echo wp_kses_post( $this->label ); ?></span>
			
			<?php
		}
	}

	/**
	 * Creates a category dropdown control for the Customizer
	 *
	 */
	class The_Wedding_Customize_Category_Dropdown_Control extends WP_Customize_Control {
		
		public function render_content() {
				
			$categories = get_categories( array( 'hide_empty' => false ) );
			
			if( !empty( $categories ) ) : ?>
					
					<label>
					
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						
						<select <?php $this->link(); ?>>
							<option value="0"><?php esc_html_e( 'All Categories', 'the-wedding' ); ?></option>
						<?php
							foreach ( $categories as $category ) :
								
								printf(	'<option value="%s" %s>%s</option>', 
									$category->term_id, 
									selected( $this->value(), $category->term_id, false ), 
									$category->name . ' (' . $category->count . ')'
								);
								
							endforeach;
						?>
						</select>
					  
					</label>
					
				<?php
			endif;
		
		}
		
	}	

 if (class_exists('WP_Customize_Control')) {
 	class Select_Control extends WP_Customize_Control {
 		public $type = 'select';

 		public function render_content() {
 			if ( empty( $this->choices ) )
					return;
			?>
			<label>
				<?php if ( ! empty( $this->label ) ) : ?>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php endif;
				if ( ! empty( $this->description ) ) : ?>
					<span class="description customize-control-description"><?php echo $this->description; ?></span>
				<?php endif; ?>
				<div class="fontPickerCustomControl">
					<select class="googleselect" <?php $this->link(); ?>>
					<?php
						foreach ( $this->choices as $value => $label )
							echo '<option class="'.esc_attr( $value ).'" value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . $label . '</option>';
					?>
					</select>
					<a href="#" class="the_wedding_font_select"><span class="the_wedding_default_theme_font"></span></a>					
					<div class="fancyDisplay" style="display:none;">
						<ul>
							<?php							
							foreach ($this->choices as $value => $label )
							{
								?>
								<li class="<?php echo esc_attr( $value ); ?>"><?php echo $label; ?></li>
								<?php
							}
							?>
						</ul>
					</div>
				</div>
			</label>
			<?php
 		}
 	}
 }
	
	
	
endif;