<?php
/**
 * Footer Settings
 *
 * Register Footer section, settings and controls for Theme Customizer
 *
 * @package The_Wedding
 */


/**
 * Adds all general settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object
 */
function the_wedding_customize_register_footer_settings( $wp_customize ) {

    // Add Section for Theme Options
    $wp_customize->add_section( 'the_wedding_section_footer', array(
        'title'    => esc_html__( 'Footer Settings', 'the-wedding' ),
        'priority' => 70,
        'panel' => 'the_wedding_options_panel' 
        )
    );

    // Add Copyright text
    $wp_customize->add_setting( 'the_wedding_theme_options[copyr_text]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'wp_kses_post'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[copyr_text]', array(
        'label'    => esc_html__( 'Copyright Text', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[copyr_text]',
        'type'     => 'text',
        'priority' => 4
        )
    );

    // Add Setting and Control for Footer Logo
    $wp_customize->add_setting( 'the_wedding_theme_options[footer_logo_check]', array(
        'default'    => true,        
        'type'      => 'option',
        'transport'    => 'refresh',
        'sanitize_callback'    => 'the_wedding_sanitize_checkbox'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_logo_check]', array(
        'label'    => esc_html__( 'Display Footer Logo', 'the-wedding' ),
        'section'    => 'the_wedding_section_footer',
        'settings'    => 'the_wedding_theme_options[footer_logo_check]',
        'type'    => 'checkbox',       
        'priority'    => 2
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_logo]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'theme_slug_sanitize_image'
        )
    );
    $wp_customize->add_control(
       new WP_Customize_Image_Control(
           $wp_customize,
           'logo',
           array
           (
            'label'      => __( 'Upload a logo', 'the-wedding' ),
            'section'    => 'the_wedding_section_footer',
            'settings'   => 'the_wedding_theme_options[footer_logo]',
            'active_callback' => 'the_wedding_footLogo_activated_callback',
            'priority' => 3
           )
       )
   );

    // Add Setting and Control for Footer Social Icons
    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons]', array(
        'default'    => true,        
        'type'      => 'option',
        'transport'    => 'refresh',
        'sanitize_callback'    => 'the_wedding_sanitize_checkbox'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons]', array(
        'label'    => esc_html__( 'Display Footer Social Icons', 'the-wedding' ),
        'section'    => 'the_wedding_section_footer',
        'settings'    => 'the_wedding_theme_options[footer_social_icons]',
        'type'    => 'checkbox',       
        'priority'    => 5
        )
    );

    // Add Setting and Control for Footer Social Icons Value
    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_facebook]', array(
        'default'    => '',
        'type'    => 'option',
        'transport'    => 'refresh',
        'sanitize_callback'    => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_facebook]', array(
        'label'    => esc_html__( 'Facebook', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_facebook]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 6
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_twitter]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_twitter]', array(
        'label'    => esc_html__( 'Twitter', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_twitter]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 7
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_gplus]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_gplus]', array(
        'label'    => esc_html__( 'Google+', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_gplus]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 8
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_pinterest]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_pinterest]', array(
        'label'    => esc_html__( 'Pinterest', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_pinterest]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 9
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_youtube]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_youtube]', array(
        'label'    => esc_html__( 'Youtube', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_youtube]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 10
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[footer_social_icons_instagram]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[footer_social_icons_instagram]', array(
        'label'    => esc_html__( 'Instagram', 'the-wedding' ),
        'section'  => 'the_wedding_section_footer',
        'settings' => 'the_wedding_theme_options[footer_social_icons_instagram]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_footer_social_activated_callback',
        'priority' => 11
        )
    );

    // Add footer background image
    $wp_customize->add_setting( 'the_wedding_theme_options[footer_background]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'theme_slug_sanitize_image'
        )
    );
    $wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'cropped_image', array(
        'section'     => 'the_wedding_section_footer',
        'settings'    => 'the_wedding_theme_options[footer_background]',
        'label'       => esc_html__( 'Footer background Image', 'the-wedding' ),
        'flex_width'  => true, // Allow any width, making the specified value recommended. False by default.
        'flex_height' => false, // Require the resulting image to be exactly as tall as the height attribute (default).
        'width'       => 1600,
        'height'      => 360,
        'priority'    => 1
    ) ) );
}
add_action( 'customize_register', 'the_wedding_customize_register_footer_settings' );