<?php
/**
 * General Settings
 *
 * Register General section, settings and controls for Theme Customizer
 *
 * @package The_Wedding
 */


/**
 * Adds all general settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object
 */
function the_wedding_customize_register_general_settings( $wp_customize ) {

    // Add Section for Theme Options
    $wp_customize->add_section( 'the_wedding_section_general', array(
        'title'    => esc_html__( 'General Settings', 'the-wedding' ),
        'priority'    => 10,
        'panel'    => 'the_wedding_options_panel' 
        )
    );
    // Add Setting and Control for Top Bar Social Icons
    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons]', array(
        'default'    => false,        
        'type'      => 'option',
        'transport'    => 'refresh',
        'sanitize_callback'    => 'the_wedding_sanitize_checkbox'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons]', array(
        'label'    => esc_html__( 'Display Social Icons', 'the-wedding' ),
        'section'    => 'the_wedding_section_general',
        'settings'    => 'the_wedding_theme_options[social_icons]',
        'type'    => 'checkbox',       
        'priority'    => 3
        )
    );
    // Add Setting and Control for Socail Icons Value
    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_facebook]', array(
        'default'    => '',
        'type'    => 'option',
        'transport'    => 'refresh',
        'sanitize_callback'    => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_facebook]', array(
        'label'    => esc_html__( 'Facebook', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_facebook]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 4
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_twitter]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_twitter]', array(
        'label'    => esc_html__( 'Twitter', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_twitter]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 5
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_gplus]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_gplus]', array(
        'label'    => esc_html__( 'Google+', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_gplus]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 6
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_pinterest]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_pinterest]', array(
        'label'    => esc_html__( 'Pinterest', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_pinterest]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 7
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_youtube]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_youtube]', array(
        'label'    => esc_html__( 'Youtube', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_youtube]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 8
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[social_icons_instagram]', array(
        'default'           => '',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[social_icons_instagram]', array(
        'label'    => esc_html__( 'Instagram', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[social_icons_instagram]',
        'type'     => 'url',
        'active_callback' => 'the_wedding_top_social_activated_callback',
        'priority' => 8
        )
    );

    // Add Settings and Controls for Top Bar Phone Section
    $wp_customize->add_setting( 'the_wedding_theme_options[top_bar_search]', array(
        'default'           => false,
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'the_wedding_sanitize_checkbox'
        )
    );  
    $wp_customize->add_control( 'the_wedding_theme_options[top_bar_search]', array(
        'label'    => esc_html__( 'Show Search bar', 'the-wedding' ),
        'section'  => 'the_wedding_section_general',
        'settings' => 'the_wedding_theme_options[top_bar_search]',
        'type'     => 'checkbox',        
        'priority' => 2
        )
    );

    // Add Settings and Controls for Layout
    $wp_customize->add_setting( 'the_wedding_theme_options[layout]', array(
            'default'           => 'right-sidebar',
        'type'              => 'option',
            'transport'         => 'refresh',
            'sanitize_callback' => 'the_wedding_sanitize_select'
    )
    );
        $wp_customize->add_control( 'the_wedding_theme_options[layout]', array(
            'label'    => esc_html__( 'Theme Layout', 'the-wedding' ),
            'section'  => 'the_wedding_section_general',
            'settings' => 'the_wedding_theme_options[layout]',
            'type'     => 'radio',
            'priority' => 9,
            'choices'  => array(
            'left-sidebar' => esc_html__( 'Left Sidebar', 'the-wedding' ),
            'right-sidebar' => esc_html__( 'Right Sidebar', 'the-wedding' ),
            'no-sidebar' => esc_html__( 'No Sidebar', 'the-wedding' )
        )
        )
    );
}
add_action( 'customize_register', 'the_wedding_customize_register_general_settings' );