<?php
/**
 * Fonts Settings
 *
 * Register Fonts section, settings and controls for Theme Customizer
 *
 * @package The_Wedding
 */


/**
 * Adds all fonts settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object
 */
function the_wedding_customize_register_fonts_settings( $wp_customize ) {
    // Add Section for Theme Options
    $wp_customize->add_section( 'the_wedding_section_fonts', array(
        'title'    => esc_html__( 'Fonts Settings', 'the-wedding' ),
        'priority' => 10,
        'panel' => 'the_wedding_options_panel'
        )
    );
    $wp_customize->add_setting( 'the_wedding_theme_options[font_name]', array(
        'default'        => 'Libre Baskerville',
        'type'              => 'option',
        'sanitize_callback' => 'the_wedding_sanitize_select'
        )
    );

    $wp_customize->add_control( new Select_Control($wp_customize, 'the_wedding_theme_options[font_name]', array(
        'label' => esc_html__( 'Font', 'the-wedding' ),
        'section' => 'the_wedding_section_fonts',
        'setting' => 'the_wedding_theme_options[font_name]',
        'priority' => 1,
        'choices'  => array(
            'abel' => esc_html__( 'Abel', 'the-wedding' ),
            'arimo' => esc_html__( 'Arimo', 'the-wedding' ),
            'bree-serif' => esc_html__( 'Bree serif', 'the-wedding' ),
            'dancing-script' => esc_html__( 'Dancing Script', 'the-wedding' ),
            'dosis' => esc_html__( 'Dosis', 'the-wedding' ),
            'droid-sans' => esc_html__( 'Droid Sans', 'the-wedding' ),
            'droid-serif' => esc_html__( 'Droid Serif', 'the-wedding' ),
            'kaushan-script' => esc_html__( 'Kaushan Script', 'the-wedding' ),
            'lato' => esc_html__( 'Lato', 'the-wedding' ),
            'libre-baskerville' => esc_html__( 'Libre Baskerville', 'the-wedding' )
            )
        )
    ) );

    $wp_customize->add_setting( 'the_wedding_theme_options[site_title_size]', array(
        'default'           => '25',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[site_title_size]', array(
        'label'    => esc_html__( 'Site Title', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[site_title_size]',
        'type'     => 'number',
        'priority' => 2
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[site_description_size]', array(
        'default'           => '16',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[site_description_size]', array(
        'label'    => esc_html__( 'Site Description', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[site_description_size]',
        'type'     => 'number',
        'priority' => 3
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h1_size]', array(
        'default'           => '30',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h1_size]', array(
        'label'    => esc_html__( 'H1 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h1_size]',
        'type'     => 'number',
        'priority' => 4
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h2_size]', array(
        'default'           => '25',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h2_size]', array(
        'label'    => esc_html__( 'H2 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h2_size]',
        'type'     => 'number',
        'priority' => 5
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h3_size]', array(
        'default'           => '22',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h3_size]', array(
        'label'    => esc_html__( 'H3 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h3_size]',
        'type'     => 'number',
        'priority' => 6
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h4_size]', array(
        'default'           => '18',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h4_size]', array(
        'label'    => esc_html__( 'H4 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h4_size]',
        'type'     => 'number',
        'priority' => 7
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h5_size]', array(
        'default'           => '15',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h5_size]', array(
        'label'    => esc_html__( 'H5 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h5_size]',
        'type'     => 'number',
        'priority' => 8
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[h6_size]', array(
        'default'           => '13',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[h6_size]', array(
        'label'    => esc_html__( 'H6 Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[h6_size]',
        'type'     => 'number',
        'priority' => 9
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[body_size]', array(
        'default'           => '14',
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'absint'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[body_size]', array(
        'label'    => esc_html__( 'Body Size', 'the-wedding' ),
        'section'  => 'the_wedding_section_fonts',
        'settings' => 'the_wedding_theme_options[body_size]',
        'type'     => 'number',
        'priority' => 10
        )
    );


}
add_action( 'customize_register', 'the_wedding_customize_register_fonts_settings' );