<?php
/**
 * Website Text Settings
 *
 * Register Website Text section, settings and controls for Theme Customizer
 *
 * @package The_Wedding
 */


/**
 * Adds all general settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object
 */
function the_wedding_customize_register_website_text_settings( $wp_customize ) {

    // Add Section for Theme Options
    $wp_customize->add_section( 'the_wedding_section_website_text', array(
        'title'    => esc_html__( 'Website Text Settings', 'the-wedding' ),
        'priority' => 11,
        'panel' => 'the_wedding_options_panel' 
        )
    );

    // Add text in header image
    $wp_customize->add_setting( 'the_wedding_theme_options[hdr_image_text_one]', array(
        'default'           => "We're getting married",
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[hdr_image_text_one]', array(
        'label'    => esc_html__( 'Header Image First Text Block', 'the-wedding' ),
        'section'  => 'the_wedding_section_website_text',
        'settings' => 'the_wedding_theme_options[hdr_image_text_one]',
        'type'     => 'text',
        'priority' => 1
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[hdr_image_text_two]', array(
        'default'           => "on August 19th 2016, Los Angeles",
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[hdr_image_text_two]', array(
        'label'    => esc_html__( 'Header Image Second Text Block', 'the-wedding' ),
        'section'  => 'the_wedding_section_website_text',
        'settings' => 'the_wedding_theme_options[hdr_image_text_two]',
        'type'     => 'text',
        'priority' => 2
        )
    );

    // Add Text Block after header image
    $wp_customize->add_setting( 'the_wedding_theme_options[txt_blk_title]', array(
        'default'           => "The Wedding Theme",
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[txt_blk_title]', array(
        'label'    => esc_html__( 'Text Block Title after header image', 'the-wedding' ),
        'section'  => 'the_wedding_section_website_text',
        'settings' => 'the_wedding_theme_options[txt_blk_title]',
        'type'     => 'text',
        'priority' => 3
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[txt_blk_subtitle]', array(
        'default'           => "A Theme To Define The Season of Love",
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[txt_blk_subtitle]', array(
        'label'    => esc_html__( 'Text Block Subtitle', 'the-wedding' ),
        'section'  => 'the_wedding_section_website_text',
        'settings' => 'the_wedding_theme_options[txt_blk_subtitle]',
        'type'     => 'text',
        'priority' => 4
        )
    );

    $wp_customize->add_setting( 'the_wedding_theme_options[txt_blk_content]', array(
        'default'           => "It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English. Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for 'lorem ipsum' will uncover many web sites still in their infancy. Various versions have evolved over the years, sometimes by accident, sometimes on purpose (injected humour and the like).",
        'type'              => 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_textarea'
        )
    );
    $wp_customize->add_control( 'the_wedding_theme_options[txt_blk_content]', array(
        'label'    => esc_html__( 'Text Block Subtitle', 'the-wedding' ),
        'section'  => 'the_wedding_section_website_text',
        'settings' => 'the_wedding_theme_options[txt_blk_content]',
        'type'     => 'textarea',
        'priority' => 5
        )
    );
}
add_action( 'customize_register', 'the_wedding_customize_register_website_text_settings' );