<?php
/**
 * Custom functions that are not template related
 *
 * @package The_Wedding
 */

 
if ( ! function_exists( 'the_wedding_default_menu' ) ) :
/**
 * Display default page as navigation if no custom menu was set
 *
 */
function the_wedding_default_menu() {
	echo '<ul id="menu-main-navigation" class="main-navigation-menu menu">'. wp_list_pages('title_li=&echo=0') .'</ul>';
}
endif;

if ( ! function_exists( 'the_wedding_footer_default_menu' ) ) :
/**
 * Display default page as navigation if no custom menu was set
 *
 */
function the_wedding_footer_default_menu() {
	echo '<div class="footer_navigation"><ul class="social">'. wp_list_pages('title_li=&echo=0&depth=1') .'</ul></div>';
}
endif;

/**
 * Change excerpt length for default posts
 *
 * @param int $length Length of excerpt in number of words
 * @return int
 */
function the_wedding_excerpt_length($length) {
	
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();

	// Return Excerpt Text
	if ( isset($theme_options['excerpt_length']) and $theme_options['excerpt_length'] >= 0 ) :
		return absint( $theme_options['excerpt_length'] );
	else :
		return 30; // number of words
	endif;
}
add_filter('excerpt_length', 'the_wedding_excerpt_length');


/**
 * Function to change excerpt length for posts in category posts widgets
 *
 * @param int $length Length of excerpt in number of words
 * @return int
 */
function the_wedding_magazine_posts_excerpt_length($length) {
    return 12;
}


/**
 * Change excerpt more text for posts
 *
 * @param string $more_text Excerpt More Text
 * @return string
 */
function the_wedding_excerpt_more( $more_text ) {
	
	return '';

}
add_filter('excerpt_more', 'the_wedding_excerpt_more');


/**
 * Set wrapper start for wooCommerce
 *
 */
function the_wedding_wrapper_start() {
	echo '<section id="primary" class="content-area">';
	echo '<main id="main" class="site-main" role="main">';
}
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
add_action('woocommerce_before_main_content', 'the_wedding_wrapper_start', 10);


/**
 * Set wrapper end for wooCommerce
 *
 */
function the_wedding_wrapper_end() {
	echo '</main><!-- #main -->';
	echo '</section><!-- #primary -->';
}
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
add_action('woocommerce_after_main_content', 'the_wedding_wrapper_end', 10);