<?php
/***
 * Template Tags
 *
 * This file contains several template functions which are used to print out specific HTML markup
 * in the theme. You can override these template functions within your child theme.
 *
 * @package The_Wedding
 */

if ( ! function_exists( 'the_wedding_top_bar' ) ): 
/**
 * Displays the top bar in the header area
 */
function the_wedding_top_bar() {

	// Get theme options from database
	$theme_options = the_wedding_theme_options();	

	// Return early if site title is deactivated
	?>
	<?php if ( true == $theme_options['social_icons'] ): ?>
		<!-- social -->
		<ul class="social">
			<?php if($theme_options['social_icons_facebook']): ?>
				<li class="facebook"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_facebook']);?>"><i class="fa fa-facebook"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['social_icons_twitter']): ?>
				<li class="twitter"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_twitter']);?>"><i class="fa fa-twitter"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['social_icons_gplus']): ?>
				<li class="google-plus"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_gplus']);?>"><i class="fa fa-google-plus"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['social_icons_pinterest']): ?>
				<li class="pinterest"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_pinterest']);?>"><i class="fa fa-pinterest-p"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['social_icons_youtube']): ?>
				<li class="youtube"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_youtube']);?>"><i class="fa fa-youtube"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['social_icons_instagram']): ?>
				<li class="instagram"><a target="_blank" href="<?php echo esc_url($theme_options['social_icons_instagram']);?>"><i class="fa fa-instagram"></i></a></li>
			<?php endif; ?>
		</ul>
		<!-- social -->
	<?php endif; ?>
	<?php if ( true == $theme_options['top_bar_search'] ): ?>
		<!-- header-search -->
		<?php get_search_form();?>	
		<!-- header-search -->
	<?php endif; ?>
<?php 
}
endif;

 
if ( ! function_exists( 'the_wedding_site_logo' ) ): 
/**
 * Displays the site logo in the header area
 */
function the_wedding_site_logo() {

	if ( function_exists( 'the_custom_logo' ) ) {
		
		the_custom_logo();
	
	} 
	
}
endif;


if ( ! function_exists( 'the_wedding_site_title' ) ): 
/**
 * Displays the site title in the header area
 */
function the_wedding_site_title() {
	
	// Get theme options from database
	$theme_options = the_wedding_theme_options();	
	
	// Return early if site title is deactivated
	if( false == $theme_options['site_title'] ) {
		return;
	}
	
	if ( is_home() or is_page_template( 'template-magazine.php' )  ) : ?>
		
		<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
	
	<?php else : ?>
		
		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
	
	<?php endif; 
	
}
endif;


if ( ! function_exists( 'the_wedding_site_description' ) ): 
/**
 * Displays the site description in the header area
 */
function the_wedding_site_description() {
	
	// Get theme options from database
	$theme_options = the_wedding_theme_options();	
	
	// Return early if site title is deactivated
	if( false == $theme_options['site_description'] ) {
		return;
	}
	
	$description = get_bloginfo( 'description', 'display' ); /* WPCS: xss ok. */
	
	if ( $description || is_customize_preview() ) : ?>

		<p class="site-description"><?php echo $description; ?></p>
	
	<?php 
	endif;
	
}
endif;


if ( ! function_exists( 'the_wedding_header_image' ) ):
/**
 * Displays the custom header image below the navigation menu
 */
function the_wedding_header_image() {
	
	// Get theme options from database
	$theme_options = the_wedding_theme_options();	
	
	// Display featured image as header image on static pages
	if( get_header_image() ) : 

		// Hide header image on front page
		if ( true == $theme_options['custom_header_hide'] and is_front_page() ) {
			return;
		}
		?>
		
		<div id="headimg" class="header-image">
			
			<?php // Check if custom header image is linked
			if( $theme_options['custom_header_link'] <> '' ) : ?>
			
				<a href="<?php echo esc_url( $theme_options['custom_header_link'] ); ?>">
					<img src="<?php echo get_header_image(); ?>" />
				</a>
				
			<?php else : ?>
			
				<img src="<?php echo get_header_image(); ?>" />
				
			<?php endif; ?>
			
		</div>
	
	<?php 
	endif;
}
endif;


if ( ! function_exists( 'the_wedding_post_image_single' ) ):
/**
 * Displays the featured image on single posts
 */
function the_wedding_post_image_single() {
	
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();
	
	// Display Post Thumbnail if activated
	if ( true == $theme_options['post_image_single'] ) :

		the_post_thumbnail('full', array( 'class' => 'img-responsive img-blog' ));

	endif;

} // the_wedding_post_image_single()
endif;


if ( ! function_exists( 'the_wedding_entry_meta' ) ):	
/**
 * Displays the date, author and categories of a post
 */
function the_wedding_entry_meta() {

	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();
	
	$postmeta = '';

	// Display categories unless user has deactivated it via settings
	if ( true == $theme_options['meta_category'] ) {
	
		$postmeta .= the_wedding_meta_category();
	
	}
	
	// Display categories unless user has deactivated it via settings
	if ( true == $theme_options['meta_comments'] ) {
	
		$postmeta .= the_wedding_meta_comments();
	
	}
		
	if( $postmeta ) {
		
		echo '<div class="entry-meta">' . $postmeta . '</div>';
			
	}

} // the_wedding_entry_meta()
endif;


if ( ! function_exists( 'the_wedding_meta_date_with_link' ) ):
/**
 * Displays the post date
 */
function the_wedding_meta_date_with_link() { 

	$time_string = sprintf( '<a class="cudate" href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date published updated" datetime="%3$s">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date('jS F, Y') )
	);

	echo '<h5>' . $time_string . '</h5>';	

}  // the_wedding_meta_date_with_link()
endif;

if ( ! function_exists( 'the_wedding_meta_date_without_link' ) ):
/**
 * Displays the post date without link
 */
function the_wedding_meta_date_without_link() { 

	$time_string = sprintf( '%1$s', esc_html( get_the_date('jS F, Y') ) );

	echo '<h5>' . $time_string . '</h5>';	

}  // the_wedding_meta_date_without_link()
endif;


if ( ! function_exists( 'the_wedding_meta_author' ) ):
/**
 * Displays the post author
 */
function the_wedding_meta_author() {
	
	$author_string = sprintf( '<a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( esc_html__( 'View all posts by %s', 'the-wedding' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
	
	return $author_string;

}  // the_wedding_meta_author()
endif;

if ( ! function_exists( 'the_wedding_posted_by' ) ) :
/**
 * Displays the post author
 */
function the_wedding_posted_by() {

	// Get theme options from database.
	$theme_options = the_wedding_theme_options();

	// Return early if author is turned off.
	if ( false == $theme_options['meta_author'] ) {
		return false;
	}

	// Get author avatar.
	$avatar = get_avatar( get_the_author_meta( 'ID' ), 32 );

	$byline = sprintf( esc_html_x( ' by %s', 'post author', 'the-wedding' ), the_wedding_meta_author() );

	echo '<h6 class="author"> ' . $avatar . $byline . '</h6>';

}  // the_wedding_posted_by()
endif;


if ( ! function_exists( 'the_wedding_meta_category' ) ):
/**
 * Displays the category of posts
 */	
function the_wedding_meta_category() { 

	return '<span class="meta-category"><i class="fa fa-folder-open"></i> ' . get_the_category_list(', ') . '</span>';
	
} // the_wedding_meta_category()
endif;


if ( ! function_exists( 'the_wedding_meta_comments' ) ):
/**
 * Displays the post comments
 */	
function the_wedding_meta_comments() { 

	// Start Output Buffering
	ob_start();
	
	// Display Comments
	comments_popup_link( esc_html__( 'Leave a comment', 'the-wedding' ), esc_html__( '1 comment', 'the-wedding' ), esc_html__( '% comments', 'the-wedding' ) );
	$comments = ob_get_contents();
	
	// End Output Buffering
	ob_end_clean();
	
	return '<span class="meta-comments"><i class="fa fa-comment"></i> ' . $comments . '</span>';	
	
} // the_wedding_meta_comments()
endif;


if ( ! function_exists( 'the_wedding_entry_tags' ) ):
/**
 * Displays the post tags on single post view
 */
function the_wedding_entry_tags() {
	
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();
	
	// Get Tags
	$tag_list = get_the_tag_list('', ' / ');
	
	// Display Tags
	if ( $tag_list && $theme_options['meta_tags'] ) : ?>
	
		<div class="entry-tags clearfix post-tags">
			<strong>Tag:</strong>
			<?php echo $tag_list; ?>			
		</div><!-- .entry-tags -->
<?php 
	endif;

} // the_wedding_entry_tags()
endif;


if ( ! function_exists( 'the_wedding_more_link' ) ):
/**
 * Displays the more link on posts
 */
function the_wedding_more_link() { ?>

	<a  href="<?php echo esc_url( get_permalink() ) ?>" class="btn"><?php esc_html_e( 'Read More', 'the-wedding' ); ?></a>

<?php
}
endif;


if ( ! function_exists( 'the_wedding_post_navigation' ) ):
/**
 * Displays Single Post Navigation
 */	
function the_wedding_post_navigation() { 
	
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();
	
	if ( true == $theme_options['post_navigation'] ) {

		the_post_navigation( array( 'prev_text' => '&laquo; %title', 'next_text' => '%title &raquo;' ) );
			
	}
	
}	
endif;


if ( ! function_exists( 'the_wedding_pagination' ) ):
/**
 * Displays pagination on archive pages
 */	
function the_wedding_pagination() { 
	
	global $wp_query;

	$big = 999999999; // need an unlikely integer
	
	 $paginate_links = paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',				
			'current' => max( 1, get_query_var( 'paged' ) ),
			'total' => $wp_query->max_num_pages,
			'next_text' => 'Next Page &raquo;',
			'prev_text' => '&laquo Previous Page',
			// 'end_size' => 5,
			// 'mid_size' => 5,
			// 'add_args' => false
		) );

	// Display the pagination if more than one page is found
	if ( $paginate_links ) : ?>
			
		<div class="post-pagination clearfix">
			<?php echo $paginate_links; ?>
		</div>
	
	<?php
	endif;
	
} // the_wedding_pagination()
endif;


/**
 * Displays credit link on footer line
 */	
function the_wedding_footer_text() {
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();
	if ( $theme_options['copyr_text']) {
	?>
		<p><?php echo sanitize_text_field($theme_options['copyr_text']); ?></p>
	<?php
	}	
}
add_action( 'the_wedding_footer_text', 'the_wedding_footer_text' );

/**
 * Displays menu on footer right side
 */	
function the_wedding_footer_menu() {
	// Display Main Navigation
	wp_nav_menu( array(
		'theme_location' => 'footer', 
		'container' => 'div', 
		'container_class' => 'footer_navigation',
		'menu_class' => 'social',		
		'echo' => true, 
		'fallback_cb' => 'the_wedding_footer_default_menu')
	);
					
}
add_action( 'the_wedding_footer_menu', 'the_wedding_footer_menu' );

/**
 * Displays menu on footer right side
 */	
function the_wedding_before_footer() { 	
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();

	// Display Footer Above Block
	?>
	<section id="bottom">
        <div class="container wow fadeInDown" data-wow-duration="1000ms" data-wow-delay="600ms">
            <div class="row">
            	<?php if ( $theme_options['footer_layout'] == 'two-columns' ) : ?>

            		<div class="col-md-6 col-sm-6">
	                	<?php if( is_active_sidebar('a-footer1') ) : ?>		
					<?php dynamic_sidebar('a-footer1'); ?>
				<?php endif; ?>                      
	                </div><!--/.col-md-6-->

	                <div class="col-md-6 col-sm-6">
	                 	<?php if( is_active_sidebar('a-footer2') ) : ?>		
					<?php dynamic_sidebar('a-footer2'); ?>
				<?php endif; ?>    
	                </div><!--/.col-md-6-->

	        <?php elseif ( $theme_options['footer_layout'] == 'three-columns' ) : ?>

	        	<div class="col-md-4 col-sm-6">
	                	<?php if( is_active_sidebar('a-footer1') ) : ?>		
					<?php dynamic_sidebar('a-footer1'); ?>
				<?php endif; ?>                      
	                </div><!--/.col-md-4-->

	                <div class="col-md-4 col-sm-6">
	                 	<?php if( is_active_sidebar('a-footer2') ) : ?>		
					<?php dynamic_sidebar('a-footer2'); ?>
				<?php endif; ?>    
	                </div><!--/.col-md-4-->

	                <div class="col-md-4 col-sm-6">
	                      <?php if( is_active_sidebar('a-footer3') ) : ?>		
					<?php dynamic_sidebar('a-footer3'); ?>
				<?php endif; ?>
	                </div><!--/.col-md-4-->

	        <?php else :?>
	        	<div class="col-md-3 col-sm-6">
	                	<?php if( is_active_sidebar('a-footer1') ) : ?>		
					<?php dynamic_sidebar('a-footer1'); ?>
				<?php endif; ?>                      
	                </div><!--/.col-md-3-->

	                <div class="col-md-3 col-sm-6">
	                 	<?php if( is_active_sidebar('a-footer2') ) : ?>		
					<?php dynamic_sidebar('a-footer2'); ?>
				<?php endif; ?>    
	                </div><!--/.col-md-3-->

	                <div class="col-md-3 col-sm-6">
	                      <?php if( is_active_sidebar('a-footer3') ) : ?>		
					<?php dynamic_sidebar('a-footer3'); ?>
				<?php endif; ?>
	                </div><!--/.col-md-3-->

	                <div class="col-md-3 col-sm-6">
	                       <?php if( is_active_sidebar('a-footer4') ) : ?>		
					<?php dynamic_sidebar('a-footer4'); ?>
				<?php endif; ?>
	                </div><!--/.col-md-3-->
            	<?php endif; ?>                
            </div>
        </div>
    </section><!--/#bottom-->
<?php }
add_action( 'the_wedding_before_footer', 'the_wedding_before_footer' );

function the_wedding_customizer_head_styles() {
	// Get Theme Options from Database
	$theme_options = the_wedding_theme_options();

	$google_fonts = array(
		'Abel' => array(
			'styles' 		=> '400',
			'character_set' => 'latin',
			'type'			=> 'sans-serif',
		),
		'Arimo' => array(
			'styles' 		=> '400,400i,700,700i',
			'character_set' => 'cyrillic,cyrillic-ext,greek,greek-ext,hebrew,latin-ext,vietnamese',
			'type'			=> 'sans-serif',
		),
		'Bree Serif' => array(
			'styles' 		=> '400',
			'character_set' => 'latin-ext',
			'type'			=> 'serif',
		),
		'Dancing Script' => array(
			'styles' 		=> '400,700',
			'character_set' => 'latin',
			'type'			=> 'cursive',
		),
		'Dosis' => array(
			'styles' 		=> '400,200,300,500,600,700,800',
			'character_set' => 'latin,latin-ext',
			'type'			=> 'sans-serif',
		),
		'Droid Sans' => array(
			'styles' 		=> '400,700',
			'character_set' => 'latin',
			'type'			=> 'sans-serif',
		),
		'Droid Serif' => array(
			'styles' 		=> '400,400italic,700,700italic',
			'character_set' => 'latin',
			'type'			=> 'serif',
		),
		'Kaushan Script' => array(
			'styles' 		=> '400',
			'character_set' => 'latin-ext',
			'type'			=> 'cursive',
		),
		'Lato' => array(
			'styles' 		=> '400,100,100italic,300,300italic,400italic,700,700italic,900,900italic',
			'character_set' => 'latin',
			'type'			=> 'sans-serif',
		),
		'Libre Baskerville' => array(
			'styles' 		=> '400,400i,700',
			'character_set' => 'latin-ext',
			'type'			=> 'serif',
		),			
	);

	$the_wedding_primary_color = $theme_options['primary_color'];

	$the_wedding_typo = $theme_options['font_name'];

	$a = implode('-', array_map('ucfirst', explode('-', $the_wedding_typo)));
	$b =str_replace("-"," ",$a);
	$styles = $google_fonts[$b]['styles'];
	$subset = $google_fonts[$b]['character_set'];
	$type = $google_fonts[$b]['type'];
	$c = str_replace(" ","+",$b);
	echo "<link href=\"https://fonts.googleapis.com/css?family=$c:$styles&subset=$subset\" rel='stylesheet'>";

	echo '<style type="text/css">';
	echo "\nbody, h1, h2, h3, h4, h5, h6{font-family:'$b', $type}";
	echo '</style>';
	echo "\n";

	echo '<style type="text/css">';

		/**
		 * Only add styles to the head of the document if the styles
		 * have been changed from default. 
		 */
		 
		// Primary design color
		if ('#e33846' != $the_wedding_primary_color ) :
			echo "\na,.post-pagination a:link, .post-pagination a:visited, #bottom ul li a:hover, #footer a:hover, .logo > p.site-description, .home_welcome h2, .home_blog_sidebar > .widget.widget_recent_entries > ul > li:before, .home_blog_sidebar > .widget.widget_recent_comments > ul > li:before, .home_blog_sidebar > .widget.widget_archive > ul > li:before, .home_blog_sidebar > .widget.widget_categories > ul > li:before, .home_blog_sidebar > .widget.widget_meta > ul > li:before, .home_blog_sidebar > .widget.widget_calendar > .calendar_wrap #wp-calendar caption { color: {$the_wedding_primary_color}!important; }\n";
			echo "\n.main-navigation-menu li.current-menu-item > a, .main-navigation-menu li.current_page_item > a, ul.social-share li a:hover, .main-navigation-menu a:active, button, input[type=\"button\"], input[type=\"reset\"], #publish_date, .btn-primary, .btn-primary:hover, .btn-primary:focus, .widget_tag_cloud .tagcloud a:hover, .widget_tag_cloud .tagcloud a:active, .entry-tags .meta-tags a:hover, .entry-tags .meta-tags a:active, .home_welcome h2:before, .home_blog_main_posts_item > .holder > .title:before, .home_blog_main_pagination .post-pagination > [class*='page-'].current, .home_blog_sidebar > .widget > .widget-tab > ul.nav-tabs > li > a:before { background: {$the_wedding_primary_color}!important; }\n";
			echo "\n.main-navigation-menu ul{border-top: 5px solid {$the_wedding_primary_color}!important;}\n";
			echo "\n.primary-navigation-wrap, #bottom {border-bottom: 5px solid {$the_wedding_primary_color}!important;}\n";
			echo "\n.home_blog_main_posts_item > .holder > .more .btn:before, .home_blog_main_pagination .post-pagination > [class*='page-'] {border: 1px {$the_wedding_primary_color} solid!important;}\n";
			echo "\n.scrollup {background: url(".get_template_directory_uri()."/images/background/up-arrow.png) center center no-repeat {$the_wedding_primary_color};}\n";
		endif;

	echo '</style>';
	echo "\n";
}
add_action( 'wp_head', 'the_wedding_customizer_head_styles' );

function the_wedding_custom_styles(){
	$theme_options = the_wedding_theme_options();
	$the_wedding_foot_back_image = absint($theme_options['footer_background']);
	echo '<style type="text/css">';
	if ($the_wedding_foot_back_image != 0) {
		$footerBackUrl = wp_get_attachment_url( $the_wedding_foot_back_image );		
		echo "\n.wraper_footer { background: url(\"{$footerBackUrl}\") center top no-repeat; background-size: cover; }\n";
	}

	if ($theme_options['layout'] === 'left-sidebar') {
		echo "\n#primary { float: right; }\n";
	} elseif ($theme_options['layout'] === 'no-sidebar') {
		echo "\n#primary { width: 100%; }\n";
		echo "\n#secondary { display: none; }\n";
	}

	if (!empty($theme_options['site_title_size'])) {
		echo "\n.logo .site-title { font-size: {$theme_options['site_title_size']}px; }\n";
	}
	if (!empty($theme_options['site_description_size'])) {
		echo "\n.logo .site-description { font-size: {$theme_options['site_description_size']}px; }\n";
	}
	if (!empty($theme_options['h1_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h1 { font-size: {$theme_options['h1_size']}px; }\n";
		echo "\n.h1, h1 { font-size: {$theme_options['h1_size']}px; }\n";
	}
	if (!empty($theme_options['h2_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h2 { font-size: {$theme_options['h2_size']}px; }\n";
		echo "\n.h2, h2 { font-size: {$theme_options['h2_size']}px; }\n";
	}
	if (!empty($theme_options['h3_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h3 { font-size: {$theme_options['h3_size']}px; }\n";
		echo "\n.h3, h3 { font-size: {$theme_options['h3_size']}px; }\n";
	}
	if (!empty($theme_options['h4_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h4 { font-size: {$theme_options['h4_size']}px; }\n";
		echo "\n.h4, h4 { font-size: {$theme_options['h4_size']}px; }\n";
	}
	if (!empty($theme_options['h5_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h5 { font-size: {$theme_options['h5_size']}px; }\n";
		echo "\n.h5, h5 { font-size: {$theme_options['h5_size']}px; }\n";
	}
	if (!empty($theme_options['h6_size'])) {
		echo "\n.home_blog_main_posts_item > .holder > .data h6 { font-size: {$theme_options['h6_size']}px; }\n";
		echo "\n.h6, h6 { font-size: {$theme_options['h6_size']}px; }\n";
	}
	if (!empty($theme_options['body_size'])) {
		echo "\nbody { font-size: {$theme_options['body_size']}px; }\n";
	}
	echo '</style>';
}
add_action( 'wp_head', 'the_wedding_custom_styles' );

if ( ! function_exists( 'the_wedding_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function the_wedding_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( 'Posted on %s', 'post date', 'the-wedding' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'the-wedding' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'the_wedding_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function the_wedding_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'the-wedding' ) );
		if ( $categories_list && the_wedding_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'the-wedding' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'the-wedding' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'the-wedding' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		/* translators: %s: post title */
		comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'the-wedding' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'the-wedding' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function the_wedding_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'the_wedding_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'the_wedding_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so the_wedding_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so the_wedding_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in the_wedding_categorized_blog.
 */
function the_wedding_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'the_wedding_categories' );
}
add_action( 'edit_category', 'the_wedding_category_transient_flusher' );
add_action( 'save_post',     'the_wedding_category_transient_flusher' );

if ( ! function_exists( 'the_wedding_footer_logo' ) ): 
/**
 * Displays the top bar in the header area
 */
function the_wedding_footer_logo() {

	// Get theme options from database
	$theme_options = the_wedding_theme_options();
	?>
	<?php if ( true == $theme_options['footer_logo_check'] ): ?>
		<div class="wraper_footer_main">
			<div class="container">
				<!-- row -->
				<div class="row">
					<div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
						<!-- footer_main -->
						<div class="footer_main">						
							<img src="<?php echo esc_url($theme_options['footer_logo']); ?>" alt="logo" width="323" height="107">
						</div>
						<!-- footer_main -->
					</div>
				</div>
				<!-- row -->
			</div>
		</div>
	<?php endif; ?>
<?php 
}
endif;

if ( ! function_exists( 'the_wedding_footer_social_icons' ) ): 
/**
 * Displays the top bar in the header area
 */
function the_wedding_footer_social_icons() {

	// Get theme options from database
	$theme_options = the_wedding_theme_options();
	?>
	<?php if ( true == $theme_options['footer_social_icons'] ): ?>
		<!-- social -->
		<ul class="social">
			<?php if($theme_options['footer_social_icons_facebook']): ?>
				<li class="facebook"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_facebook']);?>"><i class="fa fa-facebook"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['footer_social_icons_twitter']): ?>
				<li class="twitter"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_twitter']);?>"><i class="fa fa-twitter"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['footer_social_icons_gplus']): ?>
				<li class="google-plus"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_gplus']);?>"><i class="fa fa-google-plus"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['footer_social_icons_pinterest']): ?>
				<li class="pinterest"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_pinterest']);?>"><i class="fa fa-pinterest-p"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['footer_social_icons_youtube']): ?>
				<li class="youtube"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_youtube']);?>"><i class="fa fa-youtube"></i></a></li>
			<?php endif; ?>
			<?php if($theme_options['footer_social_icons_instagram']): ?>
				<li class="instagram"><a target="_blank" href="<?php echo esc_url($theme_options['footer_social_icons_instagram']);?>"><i class="fa fa-instagram"></i></a></li>
			<?php endif; ?>
		</ul>
		<!-- social -->
	<?php endif; ?>
<?php 
}
endif;

if ( ! function_exists( 'the_wedding_post_thumbnail' ) ) :
/**
 * Displays an optional post thumbnail.
 *
 * Wraps the post thumbnail in an anchor element on index views, or a div
 * element when on single views.
 *
 * Create your own the_wedding_post_thumbnail() function to override in a child theme.
 *
 * @since Twenty Sixteen 1.0
 */
function the_wedding_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	if ( is_singular() ) :
	?>

	<div class="post-thumbnail">
		<?php the_post_thumbnail(); ?>
	</div><!-- .post-thumbnail -->

	<?php else : ?>

	<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
		<?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
	</a>

	<?php endif; // End is_singular()
}
endif;

if ( ! function_exists( 'the_wedding_header_image_text' ) ) :
/**
 * Displays text in the header image
 */
function the_wedding_header_image_text() {
	$theme_options = the_wedding_theme_options(); ?>
	<div class="container">
        <!-- row -->
        <div class="row">
            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                <!-- home_banner -->
                <div class="home_banner">
                    <p class="title"><strong><?php echo esc_attr($theme_options['hdr_image_text_one']); ?></strong> <?php echo esc_attr($theme_options['hdr_image_text_two']); ?></p>
                    <div class="heartbeat"><i class="fa fa-heart-o"></i></div>
                </div>
                <!-- home_banner -->
            </div>
        </div>
        <!-- row -->
    </div>
<?php }
endif;

if ( ! function_exists( 'the_wedding_text_block_after_header_image' ) ) :
/**
 * Displays text in the header image
 */
function the_wedding_text_block_after_header_image() {
	$theme_options = the_wedding_theme_options(); ?>
	<div class="wraper_home_welcome">
        <div class="container">
            <!-- row -->
            <div class="row">
                <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                    <!-- home_welcome -->
                    <div class="home_welcome">
                        <h1><?php echo esc_attr($theme_options['txt_blk_title']); ?></h1>
                        <h2><?php echo esc_attr($theme_options['txt_blk_subtitle']); ?></h2>
                        <p><?php echo esc_attr($theme_options['txt_blk_content']); ?></p>
                    </div>
                    <!-- home_welcome -->
                </div>
            </div>
            <!-- row -->
        </div>
    </div>
<?php }
endif;

if ( ! function_exists( 'the_wedding_entry_tags' ) ) :
/**
 * Displays the post tags on single post view
 */
function the_wedding_entry_tags() {

	// Get theme options from database.
	$theme_options = the_wedding_theme_options();

	// Get tags.
	$tag_list = get_the_tag_list( '', '' );

	// Display tags.
	if ( $tag_list && $theme_options['meta_tags'] ) : ?>

		<div class="entry-tags clearfix">
			<span class="meta-tags">
				<?php echo $tag_list; ?>
			</span>
		</div><!-- .entry-tags -->

	<?php
	endif;

} // the_wedding_entry_tags()
endif;